
Unnecessary features enabled or installed.
-------

**Description:**

Whenever there are unnecessary features enabled or installed this could increase an 
attackers attack vector which could lead to serious danger such as XXE injections.


**Solution:**

Make sure al features and software available on the application/server is necessary for 
functioning. if not, uninstall or disable these services.

	